import { newE2EPage } from "@stencil/core/testing";
describe('c-swiper', () => {
  it('reacts to value change', async () => {
    const page = await newE2EPage({
      html: `<c-swiper>
      <c-swiper-tab>One</c-swiper-tab>
      <c-swiper-tab>Two</c-swiper-tab>
      <c-swiper-tab>Three</c-swiper-tab>
      <c-swiper-tab>Four</c-swiper-tab>
      <c-swiper-tab>Five</c-swiper-tab>
      </c-swiper>`,
    });
    const swiper = await page.find('c-swiper');
    swiper.setProperty('value', 1);
    await page.waitForChanges();
    const swiperTabs = await page.findAll('c-swiper-tab');
    expect(swiperTabs.length).toBe(5);
    swiperTabs[0].setProperty('value', 1);
    swiperTabs[1].setProperty('value', 2);
    swiperTabs[2].setProperty('value', 3);
    swiperTabs[3].setProperty('value', 4);
    swiperTabs[4].setProperty('value', 5);
    await page.waitForChanges();
    swiperTabs[3].setProperty('active', true);
    await page.waitForChanges();
    const activeCheck = swiperTabs[3].getAttribute('aria-selected');
    expect(activeCheck).toBe('true');
  });
  it('reacts to value change on click', async () => {
    const page = await newE2EPage({
      html: `<c-swiper>
      <c-swiper-tab>One</c-swiper-tab>
      <c-swiper-tab>Two</c-swiper-tab>
      <c-swiper-tab>Three</c-swiper-tab>
      <c-swiper-tab>Four</c-swiper-tab>
      <c-swiper-tab>Five</c-swiper-tab>
      </c-swiper>`,
    });
    const swiper = await page.find('c-swiper');
    swiper.setProperty('value', 1);
    await page.waitForChanges();
    const swiperTabs = await page.findAll('c-swiper-tab');
    expect(swiperTabs.length).toBe(5);
    swiperTabs[0].setProperty('value', 1);
    swiperTabs[1].setProperty('value', 2);
    swiperTabs[2].setProperty('value', 3);
    swiperTabs[3].setProperty('value', 4);
    swiperTabs[4].setProperty('value', 5);
    await page.waitForChanges();
    swiperTabs[3].click();
    await page.waitForChanges();
    const activeCheck = swiperTabs[3].getAttribute('aria-selected');
    expect(activeCheck).toBe('true');
  });
  it('renders disabled button', async () => {
    const page = await newE2EPage({
      html: `<c-swiper>
      <c-swiper-tab>One</c-swiper-tab>
      <c-swiper-tab>Two</c-swiper-tab>
      <c-swiper-tab>Three</c-swiper-tab>
      <c-swiper-tab>Four</c-swiper-tab>
      <c-swiper-tab>Five</c-swiper-tab>
      </c-swiper>`,
    });
    const swiper = await page.find('c-swiper');
    swiper.setProperty('value', 1);
    await page.waitForChanges();
    const swiperTabs = await page.findAll('c-swiper-tab');
    expect(swiperTabs.length).toBe(5);
    swiperTabs[0].setProperty('value', 1);
    swiperTabs[1].setProperty('value', 2);
    swiperTabs[2].setProperty('value', 3);
    swiperTabs[3].setProperty('value', 4);
    swiperTabs[4].setProperty('value', 5);
    await page.waitForChanges();
    swiperTabs[1].setProperty('disabled', true);
    await page.waitForChanges();
    swiperTabs[1].click();
    await page.waitForChanges();
    expect(page).toMatchSnapshot();
  });
});
//# sourceMappingURL=c-swiper.e2e.js.map
